@@ -1,7 +1,10 @@
+import json
 from http import HTTPStatus
 from typing import Iterable, Union
 
-from flask_restful import Resource, reqparse
+from flask import request
+from flasgger import swag_from
+from flask_restful import Resource
 
 from metadata_service.exception import NotFoundException
 from metadata_service.proxy import get_proxy_client
@@ -13,30 +16,30 @@ class ColumnDescriptionAPI(Resource):
     """
     def __init__(self) -> None:
         self.client = get_proxy_client()
-
-        self.parser = reqparse.RequestParser()
-        self.parser.add_argument('description', type=str, location='json')
-
         super(ColumnDescriptionAPI, self).__init__()
 
+    @swag_from('swagger_doc/column/description_put.yml')
     def put(self,
             table_uri: str,
-            column_name: str,
-            description_val: str) -> Iterable[Union[dict, tuple, int, None]]:
+            column_name: str) -> Iterable[Union[dict, tuple, int, None]]:
         """
-        Updates column description
+        Updates column description (passed as a request body)
+        :param table_uri:
+        :param column_name:
+        :return:
         """
         try:
+            description = json.loads(request.data).get('description')
             self.client.put_column_description(table_uri=table_uri,
                                                column_name=column_name,
-                                               description=description_val)
-
+                                               description=description)
             return None, HTTPStatus.OK
 
         except NotFoundException:
             msg = 'table_uri {} with column {} does not exist'.format(table_uri, column_name)
             return {'message': msg}, HTTPStatus.NOT_FOUND
 
+    @swag_from('swagger_doc/column/description_get.yml')
     def get(self, table_uri: str, column_name: str) -> Union[tuple, int, None]:
         """
         Gets column descriptions in Neo4j
